@@ -404,7 +404,7 @@ class ScoreCardModel(object):
 
             dict_bins_to_woe = self.dict_woe[col]
 
-            df_woe[col].map(dict_bins_to_woe)
+            df_woe[col] = df_woe[col].map(dict_bins_to_woe)
 
         return df_woe
 
@@ -952,6 +952,7 @@ class ScoreCardModel(object):
                 regroup_badrate['bins'] = regroup_badrate['bin_no']
 
             # 反转index
+            regroup_badrate['bins'] = regroup_badrate['bins'].astype(str)
             regroup_badrate = regroup_badrate.set_index('bins')
 
             # 注意regroup_badrate需要排序
